@@ -1,6 +1,6 @@
 ################################
 #### Hypothesis test for a mean direction
-#### Tsagris Michail 6/2014 
+#### Tsagris Michail 6/2014
 #### mtsagris@yahoo.gr
 #### References: Mardia Kanti V. and Jupp Peter E. (2000)
 #### Directional statistics, pg. 212
@@ -18,14 +18,14 @@ meandir.test <- function(x, mu, B = 999) {
   xbar <- colMeans(x)  ## x-bar
   m1 <- xbar/sqrt(sum(xbar^2))
   lik <- function(k) {
-    n * (p/2 - 1) * log(k) - 0.5 * n * p * log(2 * pi) + k * sum(x %*% mu) - 
+    n * (p/2 - 1) * log(k) - 0.5 * n * p * log(2 * pi) + k * sum(x %*% mu) -
       n * (log(besselI(k, p/2 - 1, expon.scaled = T)) + k)
   }
   qa0 <- optimize(lik, c(0, 100000), maximum = T)  ## log-likelihood under H0
   k0 <- qa0$maximum  ## concentration parameter under H0
-  apk0 <- (1 - p/2) * log(k0/2) + lgamma(p/2) + 
+  apk0 <- (1 - p/2) * log(k0/2) + lgamma(p/2) +
   log(besselI(k0, p/2 - 1, expon.scaled = T)) + k0
-  apk1 <- (1 - p/2) * log(k1/2) + lgamma(p/2) + 
+  apk1 <- (1 - p/2) * log(k1/2) + lgamma(p/2) +
   log(besselI(k1, p/2 - 1, expon.scaled = T)) + k1
   w <- 2 * n * (k1 * sqrt(sum(xbar^2)) - k0 * sum(mu * xbar) - apk1 + apk0)
   if (B == 1) {
@@ -42,16 +42,16 @@ meandir.test <- function(x, mu, B = 999) {
       k1 <- vmf(z)$k  ## concentration parameter under H1
       zbar <- colMeans(z)  ## z-bar
       lik <- function(k) {
-       n * (p/2 - 1) * log(k) - 0.5 * n * p * log(2 * pi) + 
-       k * sum(z %*% mu) - n * (log(besselI(k, p/2 - 1, expon.scaled = T)) + k)
+       n * (p/2 - 1) * log(k) - 0.5 * n * p * log(2 * pi) +
+       k * sum(z %*% mu) - n * (log(besselI(k, p/2 - 1, expon.scaled = TRUE)) + k)
       }
-      qa0 <- optimize(lik, c(0, 100000), maximum = T)  ## log-likelihood under H0
+      qa0 <- optimize(lik, c(0, 100000), maximum = TRUE)  ## log-likelihood under H0
       k0 <- qa0$maximum  ## concentration parameter under H0
-      apk0 <- (1 - p/2) * log(k0/2) + lgamma(p/2) + 
-      log(besselI(k0, p/2 - 1, expon.scaled = T)) + k0
-      apk1 <- (1 - p/2) * log(k1/2) + lgamma(p/2) + 
-      log(besselI(k1, p/2 - 1, expon.scaled = T)) + k1
-      wb[i] <- 2 * n * (k1 * sqrt(sum(zbar^2)) - k0 * sum(mu * zbar) - 
+      apk0 <- (1 - p/2) * log(k0/2) + lgamma(p/2) +
+      log(besselI(k0, p/2 - 1, expon.scaled = TRUE)) + k0
+      apk1 <- (1 - p/2) * log(k1/2) + lgamma(p/2) +
+      log(besselI(k1, p/2 - 1, expon.scaled = TRUE)) + k1
+      wb[i] <- 2 * n * (k1 * sqrt(sum(zbar^2)) - k0 * sum(mu * zbar) -
       apk1 + apk0)
     }
     pvalue <- (sum(wb > w) + 1)/(B + 1)
